Latest Changes
================================================================================


v0.7 -- 01/09/2012
--------------------------------------------------------------------------------

* Added the `--glob` option.
* Added the `--endpoint` option.
* Long form options were renamed from `--long_name` to `--long-name`.
* Made the creation of remote "directory keys" the default behavior and added
  the `--skip-dirkeys` option.
* Fixed issue with `--long-option` arguments not being parsed correctly.

